@@ -31,7 +31,7 @@ BEGIN {
     Win32::API::->Import("psapi","BOOL EnumProcessModules(HANDLE  hProcess, HMODULE *lphModule, DWORD   cb, LPDWORD lpcbNeeded)") or die "EnumProcessModules: $^E";  # uncoverable branch true
 }
 
-our $VERSION = '0.008'; # auto-populated from W::M::NPP
+our $VERSION = '0.009'; # auto-populated from W::M::NPP
 
 our @EXPORT_VARS = (@Win32::Mechanize::NotepadPlusPlus::Notepad::Messages::EXPORT);
 
@@ -174,8 +174,6 @@ sub _new
     my @sci_hwnds = @{$self->_enumScintillaHwnds()}[0..1];       # first two are the main editors
     @{$self}{qw/editor1 editor2/} = map Win32::Mechanize::NotepadPlusPlus::Editor->_new($_, $self->{_hwobj}), @sci_hwnds;
 
-    $self->{debugInfo} = $self->_initDebugInfo();
-
     return $self;
 }
 
@@ -2117,6 +2115,10 @@ in all instances or versions of Notepad++.
     'current ansi codepage' | Codepage number active for "ANSI" files
     'plugins'               | Space-separated list of plugin DLLs loaded
 
+The first time this method is called in any script will trigger the 
+Debug Info dialog briefly, but it is automatically closed after the 
+information is retrieved.
+
 =cut
 
 sub _initDebugInfo {
@@ -2147,6 +2149,7 @@ sub _initDebugInfo {
 
 sub getDebugInfo {
     my ($self, @keys) = @_;
+    $self->{debugInfo} = $self->_initDebugInfo() unless defined $self->{debugInfo};
     return $self->{debugInfo} unless @keys;
     return @{ $self->{debugInfo} }{map {$_ eq '-APP' ? '-APP' : lc $_ } @keys};
 }
