@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Exporter 5.57 ('import');
 
-our @EXPORT = qw/%NPPMSG %VIEW %MODELESS %STATUSBAR %MENUHANDLE %INTERNALVAR %LANGTYPE %LINENUMWIDTH %WINVER %WINPLATFORM %NOTIFICATION %DOCSTATUS %NPPIDM %BUFFERENCODING/;
+our @EXPORT = qw/%NPPMSG %VIEW %MODELESS %STATUSBAR %MENUHANDLE %INTERNALVAR %LANGTYPE %LINENUMWIDTH %WINVER %WINPLATFORM %WINMSGBOX %NOTIFICATION %DOCSTATUS %NPPIDM %BUFFERENCODING/;
 
 =encoding utf8
 
@@ -55,6 +55,8 @@ our %NPPMSG = (
     # messages
     'NPPM_ACTIVATEDOC'                                           => ((1024 + 1000) + 28),
     'NPPM_ADDTOOLBARICON'                                        => ((1024 + 1000) + 41),
+    'NPPM_ADDTOOLBARICON_DEPRECATED'                             => ((1024 + 1000) + 41), 	# v8.0
+    'NPPM_ADDTOOLBARICON_FORDARKMODE'                            => ((1024 + 1000) + 101),	# v8.0
     'NPPM_ALLOCATECMDID'                                         => ((1024 + 1000) + 81),
     'NPPM_ALLOCATEMARKER'                                        => ((1024 + 1000) + 82),
     'NPPM_ALLOCATESUPPORTED'                                     => ((1024 + 1000) + 80),
@@ -69,6 +71,7 @@ our %NPPMSG = (
     'NPPM_DMMUPDATEDISPINFO'                                     => ((1024 + 1000) + 32),
     'NPPM_DMMVIEWOTHERTAB'                                       => ((1024 + 1000) + 35),
     'NPPM_DOCSWITCHERDISABLECOLUMN'                              => ((1024 + 1000) + 89),
+    'NPPM_DOCLISTDISABLECOLUMN'                                  => ((1024 + 1000) + 89), 	# v8.1.3
     'NPPM_DOOPEN'                                                => ((1024 + 1000) + 77),
     'NPPM_ENCODESCI'                                             => ((1024 + 1000) + 26),
     'NPPM_GETAPPDATAPLUGINSALLOWED'                              => ((1024 + 1000) + 87),
@@ -120,6 +123,7 @@ our %NPPMSG = (
     'NPPM_HIDETABBAR'                                            => ((1024 + 1000) + 51),
     'NPPM_HIDETOOLBAR'                                           => ((1024 + 1000) + 70),
     'NPPM_ISDOCSWITCHERSHOWN'                                    => ((1024 + 1000) + 86),
+    'NPPM_ISDOCLISTSHOWN'                                        => ((1024 + 1000) + 86),	# v8.1.3
     'NPPM_ISMENUHIDDEN'                                          => ((1024 + 1000) + 73),
     'NPPM_ISSTATUSBARHIDDEN'                                     => ((1024 + 1000) + 75),
     'NPPM_ISTABBARHIDDEN'                                        => ((1024 + 1000) + 52),
@@ -149,6 +153,7 @@ our %NPPMSG = (
     'NPPM_SETSMOOTHFONT'                                         => ((1024 + 1000) + 92),
     'NPPM_SETSTATUSBAR'                                          => ((1024 + 1000) + 24),
     'NPPM_SHOWDOCSWITCHER'                                       => ((1024 + 1000) + 85),
+    'NPPM_SHOWDOCLIST'                                       	 => ((1024 + 1000) + 85),	# v8.1.3
     'NPPM_SWITCHTOFILE'                                          => ((1024 + 1000) + 37),
     'NPPM_TRIGGERTABBARCONTEXTMENU'                              => ((1024 + 1000) + 49),
 
@@ -345,7 +350,7 @@ our %LANGTYPE = (
     'L_DIFF'                                                     => 33,
     'L_ERLANG'                                                   => 71,
     'L_ESCRIPT'                                                  => 72,
-    'L_EXTERNAL'                                                 => 85,
+    'L_EXTERNAL'                                                 => 86,
     'L_FLASH'                                                    => 27,
     'L_FORTH'                                                    => 73,
     'L_FORTRAN'                                                  => 25,
@@ -370,6 +375,7 @@ our %LANGTYPE = (
     'L_MATLAB'                                                   => 44,
     'L_MMIXAL'                                                   => 75,
     'L_NIMROD'                                                   => 76,
+    'L_NIM'                                                      => 76, # v8
     'L_NNCRONTAB'                                                => 77,
     'L_NSIS'                                                     => 28,
     'L_OBJC'                                                     => 5,
@@ -400,6 +406,7 @@ our %LANGTYPE = (
     'L_TEX'                                                      => 24,
     'L_TEXT'                                                     => 0,
     'L_TXT2TAGS'                                                 => 83,
+    'L_TYPESCRIPT'                                               => 85, # v8.1.4
     'L_USER'                                                     => 15,
     'L_VB'                                                       => 18,
     'L_VERILOG'                                                  => 43,
@@ -473,6 +480,90 @@ our %WINPLATFORM = (
 
 );
 
+=item %WINMSGBOX
+
+Used by L<messageBox|Win32::Mechanize::NotepadPlusPlus::Notepad/"messageBox">.
+The first group set which buttons are in the dialog box.
+The second group set which button is the default/activge button.
+The third group affect the icon used for the dialog box.
+The final group encode the return values.
+
+    Key                  | Value      | Description
+    ---------------------+------------+---------------------------------------------------------------------
+    ABORTRETRYIGNORE     | 0x00000002 | The message box contains three push buttons: Abort, Retry, and Ignore.
+    CANCELTRYCONTINUE    | 0x00000006 | The message box contains three push buttons: Cancel, Try Again, Continue. Use this message box type instead of MB_ABORTRETRYIGNORE.
+    HELP                 | 0x00004000 | Adds a Help button to the message box. When the user clicks the Help button or presses F1, the system sends a WM_HELP message to the owner.
+    OK                   | 0x00000000 | The message box contains one push button: OK. This is the default.
+    OKCANCEL             | 0x00000001 | The message box contains two push buttons: OK and Cancel.
+    RETRYCANCEL          | 0x00000005 | The message box contains two push buttons: Retry and Cancel.
+    YESNO                | 0x00000004 | The message box contains two push buttons: Yes and No.
+    YESNOCANCEL          | 0x00000003 | The message box contains three push buttons: Yes and No and Cancel.
+    ---------------------+------------+---------------------------------------------------------------------
+    DEFBUTTON1           | 0x00000000 | The first button is the default button. DEFBUTTON1 is the default unless DEFBUTTON2, DEFBUTTON3, or DEFBUTTON4 is specified.
+    DEFBUTTON2           | 0x00000100 | The second button is the default button.
+    DEFBUTTON3           | 0x00000200 | The third button is the default button.
+    DEFBUTTON4           | 0x00000300 | The fourth button is the default button.
+    ---------------------+------------+---------------------------------------------------------------------
+    ICONEXCLAMATION      | 0x00000030 | An exclamation-point icon appears in the message box.
+    ICONWARNING          | 0x00000030 | An exclamation-point icon appears in the message box.
+    ICONINFORMATION      | 0x00000040 | An icon consisting of a lowercase letter i in a circle appears in the message box.
+    ICONASTERISK         | 0x00000040 | An icon consisting of a lowercase letter i in a circle appears in the message box.
+    ICONQUESTION         | 0x00000020 | A question-mark icon appears in the message box. The question-mark message icon is no longer recommended because it does not clearly represent a specific type of message and because the phrasing of a message as a question could apply to any message type. In addition, users can confuse the message symbol question mark with Help information. Therefore, do not use this question mark message symbol in your message boxes. The system continues to support its inclusion only for backward compatibility.
+    ICONSTOP             | 0x00000010 | A stop-sign icon appears in the message box.
+    ICONERROR            | 0x00000010 | A stop-sign icon appears in the message box.
+    ICONHAND             | 0x00000010 | A stop-sign icon appears in the message box.
+    ---------------------+------------+---------------------------------------------------------------------
+    RETURN_ABORT         | 3          | The Abort button was selected.
+    RETURN_CANCEL        | 2          | The Cancel button was selected.
+    RETURN_CONTINUE      | 11         | The Continue button was selected.
+    RETURN_IGNORE        | 5          | The Ignore button was selected.
+    RETURN_NO            | 7          | The No button was selected.
+    RETURN_OK            | 1          | The OK button was selected.
+    RETURN_RETRY         | 4          | The Retry button was selected.
+    RETURN_TRYAGAIN      | 10         | The Try Again button was selected.
+    RETURN_YES           | 6          | The Yes button was selected.
+    ---------------------+------------+---------------------------------------------------------------------
+=cut
+
+our %WINMSGBOX = (
+    # enum MESSAGEBOXFLAGS
+    # https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-messagebox
+    #--------------------=> -----------,
+    'ABORTRETRYIGNORE'   => 0x00000002 ,
+    'CANCELTRYCONTINUE'  => 0x00000006 ,
+    'HELP'               => 0x00004000 ,
+    'OK'                 => 0x00000000 ,
+    'OKCANCEL'           => 0x00000001 ,
+    'RETRYCANCEL'        => 0x00000005 ,
+    'YESNO'              => 0x00000004 ,
+    'YESNOCANCEL'        => 0x00000003 ,
+    #--------------------=> -----------,
+    'MB_DEFBUTTON1'      => 0x00000000 ,
+    'MB_DEFBUTTON2'      => 0x00000100 ,
+    'MB_DEFBUTTON3'      => 0x00000200 ,
+    'MB_DEFBUTTON4'      => 0x00000300 ,
+    #--------------------=> -----------,
+    'ICONEXCLAMATION'    => 0x00000030 ,
+    'ICONWARNING'        => 0x00000030 ,
+    'ICONINFORMATION'    => 0x00000040 ,
+    'ICONASTERISK'       => 0x00000040 ,
+    'ICONQUESTION'       => 0x00000020 ,
+    'ICONSTOP'           => 0x00000010 ,
+    'ICONERROR'          => 0x00000010 ,
+    'ICONHAND'           => 0x00000010 ,
+    #--------------------=> -----------,
+    'RETURN_ABORT'       => 3          ,
+    'RETURN_CANCEL'      => 2          ,
+    'RETURN_CONTINUE'    => 11         ,
+    'RETURN_IGNORE'      => 5          ,
+    'RETURN_NO'          => 7          ,
+    'RETURN_OK'          => 1          ,
+    'RETURN_RETRY'       => 4          ,
+    'RETURN_TRYAGAIN'    => 10         ,
+    'RETURN_YES'         => 6          ,
+    #--------------------=> -----------,
+);
+
 =back
 
 =head2 NOTIFICATIONS
@@ -578,6 +669,8 @@ our %NPPIDM = (
     'IDM_CMDLINEARGUMENTS'                                       => ((40000  + 7000)  + 10),
     'IDM_CONFUPDATERPROXY'                                       => ((40000  + 7000)  + 9),
     'IDM_DEBUGINFO'                                              => ((40000  + 7000)  + 12),
+    'IDM_DOCLIST_FILESCLOSE'                                     => ((40000 + 3500) + 1),		# v8.1.3
+    'IDM_DOCLIST_FILESCLOSEOTHERS'                               => ((40000 + 3500) + 2),		# v8.1.3
     'IDM_EDIT'                                                   => (40000 + 2000),
     'IDM_EDIT_AUTOCOMPLETE'                                      => (50000 + 0),
     'IDM_EDIT_AUTOCOMPLETE_CURRENTFILE'                          => (50000 + 1),
@@ -606,6 +699,9 @@ our %NPPIDM = (
     'IDM_EDIT_FILENAMETOCLIP'                                    => ((40000 + 2000) + 30),
     'IDM_EDIT_FULLPATHTOCLIP'                                    => ((40000 + 2000) + 29),
     'IDM_EDIT_FUNCCALLTIP'                                       => (50000 + 2),
+    'IDM_EDIT_INSERT_DATETIME_CUSTOMIZED'                        => ((40000 + 2000) + 86),	# v8.1.5?
+    'IDM_EDIT_INSERT_DATETIME_LONG'                              => ((40000 + 2000) + 85),	# v8.1.4
+    'IDM_EDIT_INSERT_DATETIME_SHORT'                             => ((40000 + 2000) + 84),	# v8.1.4
     'IDM_EDIT_INS_TAB'                                           => ((40000 + 2000) + 8),
     'IDM_EDIT_INVERTCASE'                                        => ((40000 + 2000) + 71),
     'IDM_EDIT_JOIN_LINES'                                        => ((40000 + 2000) + 13),
@@ -646,6 +742,7 @@ our %NPPIDM = (
     'IDM_EDIT_SORTLINES_LEXICO_CASE_INSENS_ASCENDING'            => ((40000 + 2000) + 80), # added v7.9.1
     'IDM_EDIT_SORTLINES_LEXICO_CASE_INSENS_DESCENDING'           => ((40000 + 2000) + 81), # added v7.9.1
     'IDM_EDIT_SORTLINES_RANDOMLY'                                => ((40000 + 2000) + 78), # added v7.9.1
+    'IDM_EDIT_SORTLINES_REVERSE_ORDER'                           => ((40000 + 2000) + 83),	# v8.0
     'IDM_EDIT_SPLIT_LINES'                                       => ((40000 + 2000) + 12),
     'IDM_EDIT_STREAM_COMMENT'                                    => ((40000 + 2000) + 23),
     'IDM_EDIT_STREAM_UNCOMMENT'                                  => ((40000 + 2000) + 47),
@@ -664,8 +761,8 @@ our %NPPIDM = (
     'IDM_FILE'                                                   => (40000 + 1000),
     'IDM_FILEMENU_EXISTCMDPOSITION'                              => 22,
     'IDM_FILEMENU_LASTONE'                                       => ((40000 + 1000) + 25), # updated v7.9.1
-    'IDM_FILESWITCHER_FILESCLOSE'                                => ((40000 + 3500) + 1),
-    'IDM_FILESWITCHER_FILESCLOSEOTHERS'                          => ((40000 + 3500) + 2),
+    'IDM_FILESWITCHER_FILESCLOSE'                                => ((40000 + 3500) + 1),	# renamed v8.1.3 to IDM_DOCLIST_*
+    'IDM_FILESWITCHER_FILESCLOSEOTHERS'                          => ((40000 + 3500) + 2),	# renamed v8.1.3 to IDM_DOCLIST_*
     'IDM_FILE_CLOSE'                                             => ((40000 + 1000) + 3),
     'IDM_FILE_CLOSEALL'                                          => ((40000 + 1000) + 4),
     'IDM_FILE_CLOSEALL_BUT_CURRENT'                              => ((40000 + 1000) + 5),
@@ -812,7 +909,8 @@ our %NPPIDM = (
     'IDM_LANG_MAKEFILE'                                          => ((40000 + 6000) + 18),
     'IDM_LANG_MATLAB'                                            => ((40000 + 6000) + 45),
     'IDM_LANG_MMIXAL'                                            => ((40000 + 6000) + 74),
-    'IDM_LANG_NIMROD'                                            => ((40000 + 6000) + 75),
+    'IDM_LANG_NIMROD'                                            => ((40000 + 6000) + 75),	# renamed v8.0
+    'IDM_LANG_NIM'                                               => ((40000 + 6000) + 75),  # v8.0
     'IDM_LANG_NNCRONTAB'                                         => ((40000 + 6000) + 76),
     'IDM_LANG_NSIS'                                              => ((40000 + 6000) + 29),
     'IDM_LANG_OBJC'                                              => ((40000 + 6000) + 14),
@@ -843,6 +941,7 @@ our %NPPIDM = (
     'IDM_LANG_TEX'                                               => ((40000 + 6000) + 25),
     'IDM_LANG_TEXT'                                              => ((40000 + 6000) + 16),
     'IDM_LANG_TXT2TAGS'                                          => ((40000 + 6000) + 82),
+    'IDM_LANG_TYPESCRIPT'                                        => ((40000 + 6000) + 84),	# v8.1.4
     'IDM_LANG_USER'                                              => ((40000 + 6000) + 180),
     'IDM_LANG_USER_DLG'                                          => ((40000 + 6000) + 250),
     'IDM_LANG_USER_LIMIT'                                        => ((40000 + 6000) + 210),
@@ -860,7 +959,7 @@ our %NPPIDM = (
     'IDM_MISC'                                                   => (40000 + 3500),
     'IDM_ONLINEDOCUMENT'                                         => ((40000  + 7000)  + 3),     # new name (v7.8 and newer)
     'IDM_ONLINEHELP'                                             => ((40000  + 7000)  + 3),     # old name (before v7.8)
-    'IDM_ONLINESUPPORT'                                          => ((40000  + 7000)  + 11),
+    #'IDM_ONLINESUPPORT'                                          => ((40000  + 7000)  + 11),	# removed v8.0; don't support even in previous versions because the service no longer exists
     'IDM_OPEN_ALL_RECENT_FILE'                                   => ((40000 + 2000) + 40),
     'IDM_PROJECTPAGE'                                            => ((40000  + 7000)  + 2),
     'IDM_SEARCH'                                                 => (40000 + 3000),
@@ -901,6 +1000,11 @@ our %NPPIDM = (
     'IDM_SEARCH_MARKALLEXT4'                                     => ((40000 + 3000) + 28),
     'IDM_SEARCH_MARKALLEXT5'                                     => ((40000 + 3000) + 30),
     'IDM_SEARCH_MARKEDTOCLIP'                                    => ((40000 + 3000) + 61), # v7.9.1
+    'IDM_SEARCH_MARKONEEXT1'                                     => ((40000 + 3000) + 62),	# v8.0
+    'IDM_SEARCH_MARKONEEXT2'                                     => ((40000 + 3000) + 63),	# v8.0
+    'IDM_SEARCH_MARKONEEXT3'                                     => ((40000 + 3000) + 64),	# v8.0
+    'IDM_SEARCH_MARKONEEXT4'                                     => ((40000 + 3000) + 65),	# v8.0
+    'IDM_SEARCH_MARKONEEXT5'                                     => ((40000 + 3000) + 66),	# v8.0
     'IDM_SEARCH_NEXT_BOOKMARK'                                   => ((40000 + 3000) + 6),
     'IDM_SEARCH_PASTEMARKEDLINES'                                => ((40000 + 3000) + 20),
     'IDM_SEARCH_PREV_BOOKMARK'                                   => ((40000 + 3000) + 7),
@@ -952,7 +1056,9 @@ our %NPPIDM = (
     'IDM_VIEW_ALWAYSONTOP'                                       => ((40000 + 4000) + 34),
     'IDM_VIEW_CLONE_TO_ANOTHER_VIEW'                             => 10002,
     'IDM_VIEW_CURLINE_HILITING'                                  => ((40000 + 4000) + 21),
+    'IDM_VIEW_DISTRACTIONFREE'                                   => ((40000 + 4000) + 11),	# v8.0
     'IDM_VIEW_DOCCHANGEMARGIN'                                   => ((40000 + 4000) + 45),
+    'IDM_VIEW_DOCLIST'                                           => ((40000 + 4000) + 70),	# v8.1.3
     'IDM_VIEW_DOC_MAP'                                           => ((40000 + 4000) + 80),
     'IDM_VIEW_DRAWTABBAR_CLOSEBOTTUN'                            => ((40000 + 4000) + 38),
     'IDM_VIEW_DRAWTABBAR_DBCLK2CLOSE'                            => ((40000 + 4000) + 39),
@@ -965,7 +1071,7 @@ our %NPPIDM = (
     'IDM_VIEW_EDGENONE'                                          => ((40000 + 4000) + 37), # removed v7.9.x
     'IDM_VIEW_EOL'                                               => ((40000 + 4000) + 26),
     'IDM_VIEW_FILEBROWSER'                                       => ((40000 + 4000) + 85),
-    'IDM_VIEW_FILESWITCHER_PANEL'                                => ((40000 + 4000) + 70),
+    'IDM_VIEW_FILESWITCHER_PANEL'                                => ((40000 + 4000) + 70),	# removed v8.1.3, but still supported in previous revs
     'IDM_VIEW_FOLD'                                              => ((40000 + 4000) + 50),
     'IDM_VIEW_FOLDERMAGIN'                                       => ((40000 + 4000) + 14),
     'IDM_VIEW_FOLDERMAGIN_ARROW'                                 => ((40000 + 4000) + 16),
@@ -1005,6 +1111,7 @@ our %NPPIDM = (
     'IDM_VIEW_REDUCETABBAR'                                      => ((40000 + 4000) + 5),
     'IDM_VIEW_REFRESHTABAR'                                      => ((40000 + 4000) + 40),
     'IDM_VIEW_SUMMARY'                                           => ((40000 + 4000) + 49),
+    'IDM_VIEW_SWITCHTO_DOCLIST'                                  => ((40000 + 4000) + 109),	# v8.1.3
     'IDM_VIEW_SWITCHTO_FILEBROWSER'                              => ((40000 + 4000) + 107), # v7.9.1
     'IDM_VIEW_SWITCHTO_FUNC_LIST'                                => ((40000 + 4000) + 108), # v7.9.1
     'IDM_VIEW_SWITCHTO_OTHER_VIEW'                               => ((40000 + 4000) + 72),
@@ -1031,7 +1138,9 @@ our %NPPIDM = (
     'IDM_VIEW_TOGGLE_FOLDALL'                                    => ((40000 + 4000) + 10),
     'IDM_VIEW_TOGGLE_UNFOLDALL'                                  => ((40000 + 4000) + 29),
     'IDM_VIEW_TOOLBAR_ENLARGE'                                   => ((40000 + 4000) + 3),
+    'IDM_VIEW_TOOLBAR_ENLARGE_SET2'                              => ((40000 + 4000) + 28),	# v8.0
     'IDM_VIEW_TOOLBAR_REDUCE'                                    => ((40000 + 4000) + 2),
+    'IDM_VIEW_TOOLBAR_REDUCE_SET2'                               => ((40000 + 4000) + 27),	# v8.0
     'IDM_VIEW_TOOLBAR_STANDARD'                                  => ((40000 + 4000) + 4),
     'IDM_VIEW_UNFOLD'                                            => ((40000 + 4000) + 60),
     'IDM_VIEW_UNFOLD_1'                                          => (((40000 + 4000) + 60) + 1),
