@@ -1,4 +1,4 @@
-# auto-converted from src/menuCmdID.h at Sat Mar 27 12:58:57 2021
+# auto-converted from src/menuCmdID.h at Fri Sep 10 09:49:00 2021
 package Win32::Mechanize::NotepadPlusPlus::__npp_idm;
 
 use warnings;
@@ -14,6 +14,8 @@ our %nppidm_dummyhash = (
     'IDM_CMDLINEARGUMENTS'                                       => ((40000  + 7000)  + 10),
     'IDM_CONFUPDATERPROXY'                                       => ((40000  + 7000)  + 9),
     'IDM_DEBUGINFO'                                              => ((40000  + 7000)  + 12),
+    'IDM_DOCLIST_FILESCLOSE'                                     => ((40000 + 3500) + 1),
+    'IDM_DOCLIST_FILESCLOSEOTHERS'                               => ((40000 + 3500) + 2),
     'IDM_EDIT'                                                   => (40000 + 2000),
     'IDM_EDIT_AUTOCOMPLETE'                                      => (50000 + 0),
     'IDM_EDIT_AUTOCOMPLETE_CURRENTFILE'                          => (50000 + 1),
@@ -42,6 +44,9 @@ our %nppidm_dummyhash = (
     'IDM_EDIT_FILENAMETOCLIP'                                    => ((40000 + 2000) + 30),
     'IDM_EDIT_FULLPATHTOCLIP'                                    => ((40000 + 2000) + 29),
     'IDM_EDIT_FUNCCALLTIP'                                       => (50000 + 2),
+    'IDM_EDIT_INSERT_DATETIME_CUSTOMIZED'                        => ((40000 + 2000) + 86),
+    'IDM_EDIT_INSERT_DATETIME_LONG'                              => ((40000 + 2000) + 85),
+    'IDM_EDIT_INSERT_DATETIME_SHORT'                             => ((40000 + 2000) + 84),
     'IDM_EDIT_INS_TAB'                                           => ((40000 + 2000) + 8),
     'IDM_EDIT_INVERTCASE'                                        => ((40000 + 2000) + 71),
     'IDM_EDIT_JOIN_LINES'                                        => ((40000 + 2000) + 13),
@@ -81,6 +86,7 @@ our %nppidm_dummyhash = (
     'IDM_EDIT_SORTLINES_LEXICO_CASE_INSENS_ASCENDING'            => ((40000 + 2000) + 80),
     'IDM_EDIT_SORTLINES_LEXICO_CASE_INSENS_DESCENDING'           => ((40000 + 2000) + 81),
     'IDM_EDIT_SORTLINES_RANDOMLY'                                => ((40000 + 2000) + 78),
+    'IDM_EDIT_SORTLINES_REVERSE_ORDER'                           => ((40000 + 2000) + 83),
     'IDM_EDIT_SPLIT_LINES'                                       => ((40000 + 2000) + 12),
     'IDM_EDIT_STREAM_COMMENT'                                    => ((40000 + 2000) + 23),
     'IDM_EDIT_STREAM_UNCOMMENT'                                  => ((40000 + 2000) + 47),
@@ -99,8 +105,6 @@ our %nppidm_dummyhash = (
     'IDM_FILE'                                                   => (40000 + 1000),
     'IDM_FILEMENU_EXISTCMDPOSITION'                              => 22,
     'IDM_FILEMENU_LASTONE'                                       => ((40000 + 1000) + 25),
-    'IDM_FILESWITCHER_FILESCLOSE'                                => ((40000 + 3500) + 1),
-    'IDM_FILESWITCHER_FILESCLOSEOTHERS'                          => ((40000 + 3500) + 2),
     'IDM_FILE_CLOSE'                                             => ((40000 + 1000) + 3),
     'IDM_FILE_CLOSEALL'                                          => ((40000 + 1000) + 4),
     'IDM_FILE_CLOSEALL_BUT_CURRENT'                              => ((40000 + 1000) + 5),
@@ -242,7 +246,7 @@ our %nppidm_dummyhash = (
     'IDM_LANG_MAKEFILE'                                          => ((40000 + 6000) + 18),
     'IDM_LANG_MATLAB'                                            => ((40000 + 6000) + 45),
     'IDM_LANG_MMIXAL'                                            => ((40000 + 6000) + 74),
-    'IDM_LANG_NIMROD'                                            => ((40000 + 6000) + 75),
+    'IDM_LANG_NIM'                                               => ((40000 + 6000) + 75),
     'IDM_LANG_NNCRONTAB'                                         => ((40000 + 6000) + 76),
     'IDM_LANG_NSIS'                                              => ((40000 + 6000) + 29),
     'IDM_LANG_OBJC'                                              => ((40000 + 6000) + 14),
@@ -273,6 +277,7 @@ our %nppidm_dummyhash = (
     'IDM_LANG_TEX'                                               => ((40000 + 6000) + 25),
     'IDM_LANG_TEXT'                                              => ((40000 + 6000) + 16),
     'IDM_LANG_TXT2TAGS'                                          => ((40000 + 6000) + 82),
+    'IDM_LANG_TYPESCRIPT'                                        => ((40000 + 6000) + 84),
     'IDM_LANG_USER'                                              => ((40000 + 6000) + 180),
     'IDM_LANG_USER_DLG'                                          => ((40000 + 6000) + 250),
     'IDM_LANG_USER_LIMIT'                                        => ((40000 + 6000) + 210),
@@ -289,7 +294,6 @@ our %nppidm_dummyhash = (
     'IDM_MACRO_STOPRECORDINGMACRO'                               => ((40000 + 2000) + 19),
     'IDM_MISC'                                                   => (40000 + 3500),
     'IDM_ONLINEDOCUMENT'                                         => ((40000  + 7000)  + 3),
-    'IDM_ONLINESUPPORT'                                          => ((40000  + 7000)  + 11),
     'IDM_OPEN_ALL_RECENT_FILE'                                   => ((40000 + 2000) + 40),
     'IDM_PROJECTPAGE'                                            => ((40000  + 7000)  + 2),
     'IDM_SEARCH'                                                 => (40000 + 3000),
@@ -330,6 +334,11 @@ our %nppidm_dummyhash = (
     'IDM_SEARCH_MARKALLEXT4'                                     => ((40000 + 3000) + 28),
     'IDM_SEARCH_MARKALLEXT5'                                     => ((40000 + 3000) + 30),
     'IDM_SEARCH_MARKEDTOCLIP'                                    => ((40000 + 3000) + 61),
+    'IDM_SEARCH_MARKONEEXT1'                                     => ((40000 + 3000) + 62),
+    'IDM_SEARCH_MARKONEEXT2'                                     => ((40000 + 3000) + 63),
+    'IDM_SEARCH_MARKONEEXT3'                                     => ((40000 + 3000) + 64),
+    'IDM_SEARCH_MARKONEEXT4'                                     => ((40000 + 3000) + 65),
+    'IDM_SEARCH_MARKONEEXT5'                                     => ((40000 + 3000) + 66),
     'IDM_SEARCH_NEXT_BOOKMARK'                                   => ((40000 + 3000) + 6),
     'IDM_SEARCH_PASTEMARKEDLINES'                                => ((40000 + 3000) + 20),
     'IDM_SEARCH_PREV_BOOKMARK'                                   => ((40000 + 3000) + 7),
@@ -381,7 +390,9 @@ our %nppidm_dummyhash = (
     'IDM_VIEW_ALWAYSONTOP'                                       => ((40000 + 4000) + 34),
     'IDM_VIEW_CLONE_TO_ANOTHER_VIEW'                             => 10002,
     'IDM_VIEW_CURLINE_HILITING'                                  => ((40000 + 4000) + 21),
+    'IDM_VIEW_DISTRACTIONFREE'                                   => ((40000 + 4000) + 11),
     'IDM_VIEW_DOCCHANGEMARGIN'                                   => ((40000 + 4000) + 45),
+    'IDM_VIEW_DOCLIST'                                           => ((40000 + 4000) + 70),
     'IDM_VIEW_DOC_MAP'                                           => ((40000 + 4000) + 80),
     'IDM_VIEW_DRAWTABBAR_CLOSEBOTTUN'                            => ((40000 + 4000) + 38),
     'IDM_VIEW_DRAWTABBAR_DBCLK2CLOSE'                            => ((40000 + 4000) + 39),
@@ -391,7 +402,6 @@ our %nppidm_dummyhash = (
     'IDM_VIEW_DRAWTABBAR_VERTICAL'                               => ((40000 + 4000) + 43),
     'IDM_VIEW_EOL'                                               => ((40000 + 4000) + 26),
     'IDM_VIEW_FILEBROWSER'                                       => ((40000 + 4000) + 85),
-    'IDM_VIEW_FILESWITCHER_PANEL'                                => ((40000 + 4000) + 70),
     'IDM_VIEW_FOLD'                                              => ((40000 + 4000) + 50),
     'IDM_VIEW_FOLDERMAGIN'                                       => ((40000 + 4000) + 14),
     'IDM_VIEW_FOLDERMAGIN_ARROW'                                 => ((40000 + 4000) + 16),
@@ -431,6 +441,7 @@ our %nppidm_dummyhash = (
     'IDM_VIEW_REDUCETABBAR'                                      => ((40000 + 4000) + 5),
     'IDM_VIEW_REFRESHTABAR'                                      => ((40000 + 4000) + 40),
     'IDM_VIEW_SUMMARY'                                           => ((40000 + 4000) + 49),
+    'IDM_VIEW_SWITCHTO_DOCLIST'                                  => ((40000 + 4000) + 109),
     'IDM_VIEW_SWITCHTO_FILEBROWSER'                              => ((40000 + 4000) + 107),
     'IDM_VIEW_SWITCHTO_FUNC_LIST'                                => ((40000 + 4000) + 108),
     'IDM_VIEW_SWITCHTO_OTHER_VIEW'                               => ((40000 + 4000) + 72),
@@ -457,7 +468,9 @@ our %nppidm_dummyhash = (
     'IDM_VIEW_TOGGLE_FOLDALL'                                    => ((40000 + 4000) + 10),
     'IDM_VIEW_TOGGLE_UNFOLDALL'                                  => ((40000 + 4000) + 29),
     'IDM_VIEW_TOOLBAR_ENLARGE'                                   => ((40000 + 4000) + 3),
+    'IDM_VIEW_TOOLBAR_ENLARGE_SET2'                              => ((40000 + 4000) + 28),
     'IDM_VIEW_TOOLBAR_REDUCE'                                    => ((40000 + 4000) + 2),
+    'IDM_VIEW_TOOLBAR_REDUCE_SET2'                               => ((40000 + 4000) + 27),
     'IDM_VIEW_TOOLBAR_STANDARD'                                  => ((40000 + 4000) + 4),
     'IDM_VIEW_UNFOLD'                                            => ((40000 + 4000) + 60),
     'IDM_VIEW_UNFOLD_1'                                          => (((40000 + 4000) + 60) + 1),
